# ![admin](img/admin.png) Administrez votre système

## Les sources de logiciels

![software](img/software.png)  
Debian GNU/Linux utilise le principe des dépôts en ligne pour fournir les 
applications. Ce principe permet de centraliser les logiciels et vous permet 
d'utiliser des interfaces simples pour administrer et/ou faire évoluer votre 
système : vous n'avez pas besoin de visiter les sites de logiciels.

### Le fichier sources.list

Les adresses internet des dépôts Debian sont inscrites dans le fichier 
**/etc/apt/sources.list** et les fichiers du type **/etc/apt/sources.list.d/xxx.list**.

![Un fichier sources.list pour Debian 9](img/deb9-nano-sources.png)

Détails des différentes informations du sources.list (les "#" sont des commentaires) :

- "deb" : indique que le dépôt renseigné est un dépôt de *binaires* 
(le logiciel lui-même)
- "deb-src" : indique que le dépôt renseigné est un dépôt de *sources* 
(les fichiers utilisés pour la compilation du logiciel lui-même)
- "http:·..." : l'adresse du serveur du dépôt
- "stretch", "stretch/updates" : la branche du dépôt
- "main" : la section du dépôt

Notez que vous pouvez utiliser les dépôts "génériques" `deb.debian.org` 
afin d'être redirigé vers le serveur le plus proche.

![noob](img/noob-modarp-circle-icon.png)  
**... Pourquoi "stretch" et non "stable" puisque le système est basé sur Debian Stable ??**  
"**stretch**" est le nom précis de la version installée du système. Il fixe une 
certaine version pour chaque paquet intégré dans les dépôts "stretch" (la version 
générique du noyau utilisé par exemple).  
"**stable**" est le nom générique de la version actuellement stable.  
Pour l'instant, "stretch" est la version "stable", donc vous pourriez utiliser 
l'une ou l'autre des dénominations. Mais lorsque la version "stable" de Debian 
sera "Buster", alors la version "stretch" passera en "oldstable" (ancienne stable).  
Employer le nom précis de votre version vous permet de contrôler la mise à jour 
complète de votre système en version supérieure et de maîtriser le moment de la 
mise à jour complète du système. Pas comme sur certains systèmes qui imposent 
la mise à jour  
Pour plus de détails, je vous invite à visiter la page dédiée du wiki Debian 
[https://www.debian.org/releases/index.fr.html](https://www.debian.org/releases/index.fr.html)

### À propos des dépôts, branches, sections

Debian organise ses applications au sein de dépôts. Ces dépôts sont divisés en 
branches et en sections. Pour en savoir plus sur les branches "testing" ou 
"unstable", rendez-vous au chapitre 8.8. En revanche, un mot sur les sections de dépôts.

Il existe 3 sections pour les dépôts officiels :

| section | critères de composant du paquet |
|---------|---------------------------------|
|main|conforme à DFSG sans dépendance vers "non-free"|
|contrib|conforme à DFSG mais avec des dépendances vers "non-free"|
|non-free|non conforme à DFSG|

**DFSG** (**D**ebian **F**ree **S**oftware **G**uidelines) : principes du 
logiciel libre selon Debian 
([https://www.debian.org/social_contract.fr.html#guidelines](https://www.debian.org/social_contract.fr.html#guidelines))

Seuls les paquets proposés dans la section **main** sont officiellement supportés 
par le projet Debian et 100% libres. Ceux proposés dans *contrib* et *non-free* 
ne le sont pas (ou pas totalement).

Ceci-dit, et selon votre type de matériel, il est possible que certains services 
ne puissent fonctionner sans drivers spécifiques (propriétaires). Dans ce cas, 
vous devrez modifier le fichier /etc/apt/sources.list (les détails dans le 
chapitre suivant).

- Plus de détails sur les versions de Debian dans le wiki Debian : 
[https://wiki.debian.org/fr/DebianReleases](https://wiki.debian.org/fr/DebianReleases).
- Pour les détails du sources.list, c’est par ici : 
[https://wiki.debian.org/fr/SourcesList](https://wiki.debian.org/fr/SourcesList).
- Pour une documentation complète sur la gestion des paquets Debian, c’est par là : 
[https://www.debian.org/doc/manuals/debian-reference/ch02.fr.html](https://www.debian.org/doc/manuals/debian-reference/ch02.fr.html).

### Modification des dépôts

Avant de modifier les sources des logiciels de votre système, vous devez être 
conscient des risques lors de l'utilisation des sections *non-free* et *contrib* 
de l'archive.

- l'absence de liberté pour de tels paquets de logiciel;
- l'absence de suivi de la part de Debian pour de tels paquets de logiciel 
(Debian ne peut pas suivre correctement un logiciel sans avoir accès à son code source);
- la contamination de votre système Debian totalement libre.

Maintenant que vous êtes prévenus que les *non-free* tuent les lapins roses, reprenons;

Pour modifier simplement vos dépôts, il suffit d'éditer le fichier sources.list. 
Ouvrez un terminal puis lancez cette commande en tant qu'administrateur (chap.3.8.3) :

    apt edit-sources

qui ouvrira le fichier approprié avec votre éditeur de texte par défaut 
(nano ou vim). Une fois vos modifications effectuées, sauvegardez le fichier 
([Ctrl]+'x' sous nano et ':wq' sous vim 
[http://wiki.linux-france.org/wiki/Utilisation_de_vi](http://wiki.linux-france.org/wiki/Utilisation_de_vi)).

**Exemple de ligne pour les paquets libres :**

    deb http://deb.debian.org/debian/ stable main

**Exemple de ligne pour les paquets libres et les paquets propriétaires :**

    deb http://deb.debian.org/debian/ stable main contrib non-free

Vous pourrez désormais piocher dans les 3 sections de logiciels et installer 
des drivers ou codecs non-libres.

Notez que vous pouvez aussi modifier vos sources de logiciels depuis le 
gestionnaire de paquet Synaptic en graphique (chap.8.3).

## Apt dans un terminal

![term](img/terminal.png)  
Les sections suivantes présentent des interfaces graphiques du logiciel de gestion 
de paquets **APT** (**A**dvanced **P**ackage **T**ool). Cette application est 
disponible directement depuis la ligne de commande, vous permettant 
l'administration fine de votre système.

Cette section présente les commandes de base pour gérer les paquets sur Debian 
avec Apt depuis votre émulateur de terminal.

Debian peut également utiliser "aptitude", un autre gestionnaire de paquets 
avec une syntaxe et un comportement différents. Ce manuel étant destiné aux 
débutants, nul besoin de ces commandes ici : pour en savoir plus, visitez 
la page dédiée 
([https://wiki.debian.org/fr/Aptitude](https://wiki.debian.org/fr/Aptitude)) 
du wiki Debian.

### Les commandes 'utilisateur' de recherche et d'information

Ces commandes peuvent être lancées en tant que simple utilisateur car elles 
n'affectent pas votre système.

|commande|description|
|--------|-----------|
|apt show *toto*|afficher les informations du paquet *toto*|
|apt search *toto*|rechercher les paquets qui correspondent à *toto*|
|apt-cache policy *toto*|Affiche les versions disponibles de *toto*|

### Les commandes 'administrateur' de maintenance

Ces commandes nécessitent les droits de l'administrateur "root" car elles 
affectent votre système. Pour passer en mode administrateur depuis un terminal, 
lancez simplement "**su -**" : le mot de passe administrateur vous sera demandé.

|commande|description|
|--------|-----------|
|apt update|Mise à jour des métadonnées des dépôts.|
|apt install *toto*|Installation du paquet *toto* avec ses dépendances.|
|apt upgrade|Mise à jour sécurisée des paquets installés.|
|apt dist-upgrade|Mise à jour des paquets installés en installant ou |
||supprimant d'autres paquets si nécessaire.|
|apt remove *toto*|Supprimer le paquet *toto* en laissant ses |
||fichiers de configuration.|
|apt-get autoremove|Supprimer les paquets installés automatiquement |
||lorsqu'ils ne sont plus nécessaires.|
|apt purge *toto*|Purger le paquet *toto* ainsi que ses |
||fichiers de configuration.|
|apt-get clean|Nettoyer le cache local des paquets installés.|
|apt-get autoclean|Nettoyer le cache des fichiers des paquets périmés.|
|apt-mark showmanual|Passe un paquet en "installé manuellement".|

Pour le détail des commandes et les correspondances apt/aptitude, visitez 
la page dédiée du manuel Debian 
([https://www.debian.org/doc/manuals/debian-reference/ch02.fr.html](https://www.debian.org/doc/manuals/debian-reference/ch02.fr.html)).

**Tout-en-une !** Mettre à jour les infos des dépôts + mettre à jour votre 
système + nettoyer les paquets en cache simplement avec une commande en mode 
administrateur :

    apt update && apt dist-upgrade && apt-get autoclean

Comme quoi, gérer son système avec le terminal, c'est pas si compliqué.

**Apt vs Apt-get**

Apt est en cours de simplification et propose désormais une syntaxe simplifiée 
pour une partie de ses commandes et options. Vous trouverez donc les deux 
syntaxes (*apt* et/ou *apt-get*) employées dans ces pages et la plupart des 
documentations GNU/Linux.

### Les backports ou le rétro-portage des paquets

Debian dispose de dépôts particuliers nommés **backports** qui contiennent 
des **versions plus récentes** de certaines applications. Ces dépôts ne sont 
pas activés par défaut, mais ils ne présentent pas de risques particuliers pour 
votre système : les dépôts "réguliers" restent prioritaires lors des mises à 
jour, seules les applications explicitement installées depuis les backports 
puiseront dans ces dépôts spécifiques.

![noob](img/noob-modarp-circle-icon.png)  
**... c'est des trucs par derrière les "backports" ?**  
Non, rien à voir avec les "backdoors" (portes dérobées) servant à espionner votre 
machine sur les systèmes propriétaires.  
**Backport** ou **Rétro-portage** est un mécanisme qui permet d'adapter 
(de *porter*) une application présente dans les dépôts de développement Debian, 
pour la rendre utilisable sur une version "stable".  
Par exemple, les développeurs Debian prennent une version récente de LibreOffice 
dans les dépôts de développement, et re-compilent (fabriquent) le paquet 
contenant l'application en prenant en compte les dépendances présentes dans la 
version stable.

Pour plus d'informations sur les backports, vous pouvez consulter la documentation 
Debian à ce sujet 
([https://wiki.debian.org/fr/Backports](https://wiki.debian.org/fr/Backports)). 
Si vous recherchez une application vous avez deux solutions : utiliser l'outil 
de recherche 
([https://backports.debian.org/Packages/](https://backports.debian.org/Packages/)) [en] 
ou la recherche par catégorie 
([https://packages.debian.org/fr/jessie-backports/](https://packages.debian.org/fr/jessie-backports/)).

## Synaptic : le gestionnaire de paquet complet

![synaptic](img/synaptic-icon.png)  
**Synaptic** est l'interface graphique complète de votre gestionnaire de paquets 
Debian. Il vous permet une vision totale des paquets proposés, installés ou non. 
Il est beaucoup plus détaillé que "Logiciels" ou "Découvrir" (décrits dans les 
chapitres suivants) puisqu'il affiche l'**intégralité** des paquets disponibles 
(bibliothèques incluses).

- Il fournit les mêmes fonctions que l'outil apt-get ou apt.
- Vous aurez besoin du mot de passe de l'administrateur pour ouvrir et utiliser Synaptic.
- Une connexion internet active est également nécessaire pour mettre à jour ou 
installer vos logiciels.

### Interface principale

La fenêtre de Synaptic se découpe en 4 zones : la barre d'outils en haut, le volet 
de gauche qui permet de filtrer les paquets, la zone qui contient la liste des 
paquets et en dessous la zone où s'affiche la description d'un paquet sélectionné 
avec un clic.

Devant chaque paquet on remarque un petit carré (blanc pour les paquets non 
installés, vert pour les paquets installés et rouge pour les paquets cassés).

![Synaptic : interface par défaut du gestionnaire de paquets](img/synaptic-default.png)

**La première chose à faire** au lancement de Synaptic est de **cliquer sur 
"Recharger"** afin de vérifier les informations sur les dépôts et les 
applications disponibles.

![Synaptic : vérifier les dépôts](img/synaptic-refresh-icon.png)

N'hésitez pas à cliquer sur tous les menus pour explorer et vous familiariser 
avec Synaptic. C'est un bon moyen de découvrir ses nombreuses fonctions.

N'ayez pas peur pour votre système, rien ne sera fait sans avoir cliqué sur 
"Appliquer" : un message de confirmation vous sera toujours demandé.

### Gestion des dépôts

Les dépôts permettent de mettre à jour vos applications et d'installer des 
paquets supplémentaires. Ils ont été configurés lors de l'installation mais 
vous pouvez les modifier à tout moment selon vos besoins.

Ouvrez le gestionnaire de paquets Synaptic (à partir du menu Système > 
Gestionnaire de paquets Synaptic).  
Dans le menu de Synaptic, cliquez sur "Configuration" puis "Dépôts". Selon que vous 
soyez sur Gnome ou pas, les dépôts de logiciels se présentent sous deux formes.

La gestion des dépôts sur le bureau **GNOME** passe par une interface 
"à cocher" explicite :

![Synaptic : gestion des sources depuis Gnome](img/deb9-synaptic-sources-gtk.png)

La gestion des dépôts sur les autres bureaux comme **Xfce** ou **LXDE** est en 
mode "texte" avec les adresses affichées :

![Synaptic : gestion des dépôts depuis Xfce.](img/deb9-synaptic-sources.png)

Les informations reprennent celles du fichier /etc/apt/sources.list cité au 
chapitre 8.1.1. Il ne vous reste plus qu'à modifier vos sources de dépôts à 
votre convenance. Cliquez simplement sur une source pour l'ajouter à vos dépôts.

Vous serez invités à recharger la liste des dépôts pour que les modifications 
soient prises en compte.  
Notez que si vous souhaitez utiliser l'interface "à cocher" sur un bureau 
Xfce ou LXDE, il suffit d'installer le paquet "software-properties-gtk".

### Mise à jour du système

Avant de mettre votre système à jour, il est nécessaire de "Recharger" la 
liste des paquets en cliquant sur l'icône correspondant ou en allant dans le 
menu "Édition > Actualiser la liste des paquets" (ou encore [Ctrl]+'r' si vous 
préférez utiliser le raccourci clavier). Cette action permet d'aller vérifier 
si la version des paquets présents sur votre machine est bien la plus récente.

![vérification des dépôts](img/synaptic-refresh-icon.png)

Ensuite cliquez sur "Tout mettre à niveau" ou menu  "Édition > Sélectionner 
la totalité des mises à jour".

![demande de mise à jour](img/synaptic-upgrade-icon.png)

Une fenêtre apparaît avec la liste des paquets qui vont être mis à jour et 
les dépendances additionnelles si nécessaires :

![ajout des dépendances](img/synaptic-upgrade-resume.png)

Il ne vous reste plus qu'à cliquer sur "Appliquer", une confirmation vous sera demandée :

![appliquer la mise à jour](img/synaptic-upgrade-apply.png)

![confirmation des modifications](img/synaptic-upgrade-confirm.png)

La mise à jour du système commence avec le téléchargement des paquets, 
puis l'installation. Un message vous informe en fin de processus :

![téléchargement des paquets](img/synaptic-upgrade-dwl.png)

![mise à jour des paquets](img/synaptic-upgrading.png)

![système à jour](img/synaptic-upgraded.png)

### Rechercher un logiciel

**Si vous ne connaissez pas le nom du paquet** dont vous avez besoin, vous 
pouvez parcourir la liste en filtrant par catégorie, état, origine, etc.

Exemple si vous cherchez un jeu, cliquez sur catégorie dans le volet de gauche 
puis faites défiler jusqu'à jeux et divertissements (encore un clic) et tous 
les paquets concernant les jeux et divertissements s'affichent.

**Si vous connaissez le nom du paquet** ou cherchez quelque chose de précis, 
cliquez sur *Rechercher* et entrez vos mots clé de recherche dans la 
fenêtre qui apparaît.

D'autres filtres de recherche sont disponibles, cliquez pour explorer.

#### Voir les détails complets d'un paquet

En cliquant sur un paquet on obtient la description du dit paquet dans le volet 
bas de Synaptic. Pour encore plus d'information, vous pouvez afficher les 
propriétés du paquet avec un clic droit/propriétés, ou en passant par le 
menu "Paquet".

Vous saurez ainsi tout, absolument tout sur le paquet : dépendances, 
fichiers installés , espace occupé et version.

### Installer / supprimer une application

#### Installer

**Pour installer** un ou plusieurs paquets, clic-droit sur la petite case 
devant le nom du paquet et "sélectionnez pour installation".

![Synaptic : sélectionner un paquet pour installation](img/synaptic_install1.png)

Si le paquet nécessite l'installation d'autres paquets pour fonctionner (les 
dépendances), ceux-ci seront automatiquement ajoutés à la sélection.

Il ne reste plus qu'à cliquer sur "Appliquer" et confirmer le récapitulatif 
des changements à appliquer.

![Synaptic : récapitulatif des changements en attente](img/synaptic_install2.png)

![Synaptic : application des changements en cours](img/synaptic_install3.png)

![Synaptic : installation de pacman](img/synaptic_install4.png)

#### Désinstaller

Comme pour l'installation, clic-droit sur la case devant le nom du paquet et 
"sélectionnez pour suppression". Cliquez sur "Appliquer".

**La suppression simple** conserve les fichiers de configuration des paquets 
dans votre système, au cas où vous souhaiteriez les réinstaller.

**Pour supprimer aussi les fichiers de configuration**, il faut utiliser le 
choix "sélectionner pour suppression complète" (équivaut à "purge" en 
ligne de commande dans un terminal).

#### Ré-installer

Il arrive parfois que l'on veuille ré-installer un paquet qui l'est déjà, dans 
ce cas choisissez l'option "sélectionner pour réinstallation". Cela permet, 
par exemple, de mettre à jour la configuration par défaut d'une application.

#### Nettoyer les paquets inutiles

Les applications de votre système fonctionnent sur le principe des dépendances : 
certains paquets ont besoins d'autres paquets pour fonctionner correctement.  
Lors de la suppression d'une application, les dépendances ne sont pas toujours 
supprimées. Pour vérifier et désinstaller au besoin les paquets inutiles, on 
utilise les filtres de Synaptic.

Lancez Synaptic puis sélectionnez "État" dans les filtres en bas à gauche. Si la 
ligne "Installés (pouvant être supprimés)" est présente, on la sélectionne 
pour afficher les paquets à supprimer :

![Synaptic : paquets inutiles](img/deb9-synaptic-paquets-inutiles.png)

Il reste alors à sélectionner les paquets listés puis d'un clic-droit, 
choisir "sélectionner pour suppression complète" puis "Appliquer".

#### Supprimer les résidus de configuration

Certaines applications utilisent des fichiers de configuration qui peuvent rester 
en place même après la suppression de l'application. Comme pour les paquets 
inutiles (chapitre précédent), on utilise synaptic pour vérifier et supprimer 
les fichiers résiduels.  
Lancez Synaptic, choisissez le filtre "État" puis, si vous voyez "Non installés 
(résidus de configuration)", sélectionnez l'entrée afin de nettoyer les fichiers 
listés (clic-droit > sélectionner pour suppression complète) :

![Synaptic : résidus de configuration](img/deb9-synaptic-paquets-residus.png)

### Préférences de Synaptic

Catégorie qui porte bien son nom. Comme dans la plupart des applications, la 
fameuse section "Préférences"... **Mais gardez à l'esprit que Synaptic n'est pas 
un logiciel comme les autres :** il gère tous les programmes installés sur votre 
système. Lorsque vous supprimez un programme, il ne va pas dans la corbeille.

Après ces avertissements un peu flippants, passons donc aux réglages disponibles 
sur Synaptic. La fenêtre des préférences présente 6 onglets et se lance depuis 
le menu "Configuration > Préférences" :

![Synaptic : fenêtre des préférences](img/synaptic_preferences.png)

- **Général :** les entrées sont explicites. Note : il est possible de décocher 
la case "traiter les paquets recommandés comme des dépendances". Si cela peut 
être utile lorsque l'on souhaite garder un système ultra-léger, cela peut aussi 
poser des problèmes lors des installations futures de nouveaux paquets. Cette 
option est donc à manipuler avec précaution.
- **Colonnes et polices :** permet d'afficher/masquer certaines colonnes dans 
la liste des paquets et d'ajuster la police de caractères si besoin.
- **Couleurs :** choisissez ici les couleurs respectives des paquets selon leur état.
- **Fichiers :** lorsque vous installez un logiciel, il est tout d'abord stocké 
*en cache* dans un répertoire de votre système avant d'être décompressé et installé. 
Ces paquets peuvent prendre de la place au fur et à mesure de votre utilisation. 
Ici, vous pourrez les supprimer ou configurer une action automatique.
- **Réseau :** la façon dont Synaptic est connecté à internet. Si votre situation 
demande de modifier ces paramètres, vous le saurez :)
- **Distribution :** comment s'effectuent les mises à jour. Explicite. 
**Dans le doute, ne pas modifier**.


**Rappel :** le terminal (chap.8.2) peut faire tout ça bien plus vite et avec 
moins de manipulation.

## Découvrir : la logithèque KDE

Le gestionnaire de paquets Synaptic est l'interface par défaut pour le 
gestionnaire de logiciels, mais il est parfois "trop" complet. Gnome utilise 
"**Logiciels**" pour gérer les applications de manière simplifiée, KDE intègre 
"**Découvrir**", une logithèque intuitive et efficace.

**Découvrir** se lance simplement depuis le menu principal KDE > Applications > 
Système > Logithèque :

![lanceur de la logithèque KDE](img/deb9-kde-updeb-menu-decouvrir.png)

![Page d'accueil de la logithèque KDE "Découvrir"](img/deb9-kde-updeb-decouvrir.png)

### Gérer vos applications avec la logithèque KDE

**Rechercher et installer** une application depuis le champ de recherche dédié ou 
en visitant les catégories de la logithèque. Un clic sur le bouton "Installer" suffit :

![Rechercher un logiciel sur Découvrir](img/deb9-kde-updeb-decouvrir-search.png)

![Visiter les catégories de Découvrir](img/deb9-kde-updeb-decouvrir-categorie.png)

**Installer des composants graphiques** supplémentaires pour l'environnement Plasma 
depuis la section "Modules complémentaires Plasma" (ici l'extension RedShift pour 
la fatigue visuelle) :

![Sélection de Redshift pour installation](img/deb9-kde-updeb-decouvrir-plasma.png)

**Supprimer une application** de la même façon, avec le bouton dédié :

![suppression d'un paquet sur KDE](img/deb9-kde-updeb-decouvrir-remove.png)

Une confirmation vous sera demandée pour toute action sur les logiciels ainsi que 
le mot de passe administrateur. Le processus sera ensuite lancé en arrière-plan. 
Vous pourrez suivre la progression des modifications depuis la zone de 
notification de KDE.

### Mise à jour avec Découvrir

Lorsque KDE vous notifie une ou plusieurs mises à jour, c'est "Découvrir" qui 
se lance pour les effectuer :

![notification de la mise à jour et lancement de "Découvrir"](img/deb9-kde-updeb-notify-decouvrir.png)

Il vous suffit alors de cliquer sur "Tout mettre à jour" puis de confirmer 
l'opération avec le mot de passe administrateur.

![lancement de la mise à jour](img/deb9-kde-updeb-decouvrir-update.png)

Comme pour la gestion des logiciels, vous pourrez suivre le processus depuis 
la zone de notification de KDE.

## Logiciels : le gestionnaire de paquets simplifié

![gsoft](img/gnome-software.png)  
**Logiciels** est un gestionnaire simplifié pour les applications Debian. Il 
permet de rechercher, installer, supprimer ou mettre à jour les paquets 
logiciels contenant vos applications. Vous le trouverez dans la catégorie 
"Système" de vos menus ou directement depuis la zone de recherche Gnome en 
tapant "Logiciels".

![Logiciel : l'interface par défaut sur Debian.](img/deb9-gnome-logiciels.png)

### Recherchez avec Logiciels

Directement depuis le bouton de recherche en forme de loupe, ou en cliquant sur 
une des catégories affichées :

![Rechercher une application avec son nom.](img/deb9-gnome-logiciels-search.png)

![Rechercher une application en visitant les catégories.](img/deb9-gnome-logiciels-categories.png)

### Installez avec Logiciels

**Installez une application** simplement en cliquant sur sa fiche, puis 
"Installer". Le mot de passe administrateur sera demandé. Vous pourrez suivre 
la progression dans la fenêtre principale puis lancer directement l'application 
nouvellement téléchargée.

![Sélectionner un logiciel pour installation.](img/deb9-gnome-logiciels-install.png)

![Mot de passe administrateur demandé.](img/deb9-gnome-logiciels-auth.png)

![L'installation se lance.](img/deb9-gnome-logiciels-installing.png)

![L'installation est réussie : vous pouvez lancer directement votre logiciel.](img/deb9-gnome-logiciels-installed.png)

### Supprimez avec Logiciels

**Désinstaller une application** simplement en visitant la catégorie "Installées" 
(en haut de l'interface) puis en cliquant sur le bouton prévu. Une confirmation 
vous sera demandée :

![Sélectionner un logiciel pour suppression.](img/deb9-gnome-logiciels-remove.png)

![confirmation](img/deb9-gnome-logiciels-remove-confirm.png)

### Mise à jour avec Logiciels

**Mettre à jour son système** depuis la section dédiée "Mises à jour" qui 
vous indiquera les mises à jour disponibles et/ou déjà téléchargées. Si aucune 
mise à jour n'est disponible, vous pouvez vérifier les dépôts grâce au bouton 
dédié en haut à gauche.  
Dans notre exemple, une série de mise à jour incluant la "mise à jour du système 
d'exploitation" exige un redémarrage. Vous pouvez lister l'ensemble des 
applications mises à jour dans ce lot en cliquant sur l'entrée concernée :

![onglet des mises à jour](img/deb9-gnome-logiciels-update.png)

![vérification des mises à jour disponibles](img/deb9-gnome-logiciels-update-check.png)

Il vous reste alors à redémarrer en cliquant sur le bouton dédié.  
![](img/deb9-gnome-logiciels-update-reboot.png)  

![redémarrer pour appliquer les mises à jour](img/deb9-gnome-logiciels-update-rebooting.png)

Notez que pour des mises à jour moins importantes, le redémarrage n'est pas nécessaire.

## Nettoyer votre système

![clean](img/clean.png)  
Même si la capacité des disques durs a largement augmenté ces dernières années, 
vous pouvez avoir besoin de place sur votre système. Il existe quelques scripts 
automatisant le nettoyage du système, mais j'avoue préférer vérifier avant 
de **rm** (pour **r**e**m**ove. chap.11.2).

### Informations sur l'espace disque

La première chose à faire est bien sûr de connaître l'espace utilisé sur votre 
disque. Plusieurs outils à votre disposition :

**Espace disponible en console :** Un aperçu de l'espace disponible selon vos points de montage (disques et partitions) :

    df -h

**Lister les répertoires selon leur taille** :

    du -ks * | sort -nr

**Ncdu** : l'analyseur d'espace disque en console. Pour le lancer, taper 
simplement "ncdu" dans votre terminal. Pour l'installer (en root) :

    apt update && apt install ncdu

![Ncdu lancé dans le répertoire utilisateur](img/ncdu.png)

**Baobab** : l'analyseur d'espace disque en mode graphique intégré à Gnome :

![Baobab : analyseur d'espace disque pour Gnome](img/baobab.png)

**Fslint** : l'analyseur de doublons, liens cassés, répertoires vides, mauvais 
encodage, etc. À utiliser avec prudence : vérifiez bien les changements en 
attente avant de valider le processus.

### Nettoyage des paquets

**Apt**/aptitude/dpkg sont les utilitaires courants de gestion des paquets sur 
Debian. Lorsque vous installez un paquet, son archive-source/deb est stockée sur 
votre système (dans /var/cache/apt/archives/) en vue d'une réinstallation 
éventuelle hors liaison internet. Pour nettoyer le **cache apt**, une simple 
commande en mode administrateur (chap.3.8.3) :

    apt-get clean

Une fois le cache des paquets installés nettoyé, vous pouvez aussi éliminer les 
paquets inutiles sur votre système, ainsi que leurs fichiers de configuration. 
**Attention !** Pensez à bien vérifier la liste des paquets prévus pour être 
supprimés avant de valider :

    apt-get autoremove --purge


### Vider les corbeilles

3 types de corbeilles sont à prendre en compte :

**La corbeille utilisateur** : ~/.local/share/Trash/ . Vous pouvez la vider 
depuis votre gestionnaire de fichier ou depuis un terminal :

    rm -Rf ~/.local/share/Trash/*

**La corbeille administrateur** : /root/.local/share/Trash/ . Pour la vider 
proprement depuis un terminal administrateur :

    rm -Rf /root/.local/share/Trash/*

**Les corbeilles externes** : situées sur vos disques dur externes, elles sont 
généralement nommées '/media/votre_disque/.Trash_1000', ce qui correspond à 
votre identifiant utilisateur (uid).

### Nettoyage des "caches" applications

Certaines applications utilisent un dossier "cache" afin d'y stocker images, 
vidéos, informations diverses pour accélérer l'exécution du logiciel. Ces données 
ne prennent pas trop de place en utilisation courante, mais si vous détectez 
(grâce aux outils d'analyse décrits plus haut) un dossier trop volumineux, 
n'hésitez pas à le supprimer.

Chaque application a une gestion différente de son propre cache; certaines le 
vident systématiquement à la fermeture de l'application, d'autres, stockent 
leurs informations dans /tmp qui se videra à la fermeture de la session, 
d'autres encore gardent toutes les infos dans un dossier spécifique.

Pour Firefox par ex, vous pouvez vider le cache depuis le menu de préférences, 
et même automatiser cette opération à chaque fermeture de l'application.

### Nettoyage des aperçus

À chaque fois que vous visionnez une photo, que vous ouvrez un répertoire 
d'images, un aperçu est créé. Cet aperçu (thumbnail) est stocké dans un 
répertoire afin de pouvoir y revenir en cas de réouverture de l'image. Le souci 
est que si une image est effacée, son aperçu est conservé. Il en résulte un 
stockage inutile d'aperçus périmés.  
Pour nettoyer ces fichiers, il suffit de supprimer le dossier 
concerné : ~/.thumbnails.

    rm -Rf ~/.thumbnails

Ce dossier sera créé à nouveau à la prochaine ouverture d'une image.

## Installation de paquets externes ".deb"

Debian GNU/Linux utilise le système des dépôts de paquets afin d'assurer une 
meilleure gestion et une plus grande sécurité. Mais il peut arriver que vous 
ayez besoin d'installer un paquet externe au format ".deb".

![noob](img/noob-modarp-circle-icon.png)  
**... C'est qui ce "deb" ??**  
**deb** est l'abréviation de "debian", la maison mère. Debian utilise, pour 
distribuer ses applications, un format d'archive particulier, le ".deb". 
C'est un format de compression comme le ".zip" que vous utilisez pour sauvegarder 
des données. Ces archives ".deb" sont reconnues par les différents gestionnaires 
de paquets Debian (APT et son interface graphique, Synaptic) et peuvent ainsi 
être pris en charge plus facilement.

### Installation graphique avec gdebi

Gdebi est un utilitaire graphique qui permet d'installer un paquet externe au 
format ".deb" tout en gérant les dépendances.

Pour l'installer, recherchez "gdebi" dans votre gestionnaire de paquets 
("Synaptic", "Découvrir" ou "Logiciels") ou plus simplement depuis un terminal 
en mode administrateur grâce à "**su**" (chap.3.8.3) :

    apt update && apt install gdebi

Lorsque vous téléchargez un paquet externe *debian*, effectuez un clic-droit 
dessus > "Ouvrir avec Gdebi".

### Installation en console avec dpkg

Dpkg est un utilitaire de gestion des paquets comme apt, mais il ne gère pas 
les dépendances. Cela signifie que si vous utilisez dpkg pour installer un paquet 
externe, il faudra installer les paquets dépendants un à un depuis votre 
terminal. Dpkg est intégré par défaut sur Debian et s'utilise en mode administrateur.

**Pour installer un paquet :**

    dpkg -i adresse_du_paquet.deb

Si des dépendances sont manquantes, un message d'erreur vous le signalera, 
il suffira alors d'installer les dépendances de manière classique avec apt :

    apt install paquet_dépendant1 paquet_dépendant2 ...

Puis relancez l'installation de votre paquet externe :

    dpkg -i adresse_du_paquet.deb

**Pour supprimer un paquet :**

    dpkg --purge nom_du_logiciel

## Qui c’est ce Sid ?

Tout d'abord, il faut savoir qu'il existe simultanément **plusieurs branches 
des distributions Debian**.

Les distributions **oldstable**, **stable**, **testing** et **unstable**, 
ainsi que la branche **experimental**.

**La distribution Stable** est la distribution officielle de Debian, celle qui 
a cours à cet instant, elle est maintenue et mise à jour par les équipes de 
Debian. Seules des mises à jour de sécurité et les corrections de bugs sont 
effectuées. C'est la version recommandée à privilégier.

**La distribution Oldstable** est l'ancienne stable, Elle est, en général, 
supportée par les équipes de Debian pendant un an après la sortie de la nouvelle 
stable. Ensuite, elle peut continuer à vivre si suffisamment de personnes ou 
d'entreprises continuent d'assurer la maintenance, on appelle alors cela une 
distribution LTS (Support à long terme) : on prolonge sa durée vie.

**La distribution Testing** est la future version stable. Elle sert à préparer 
la prochaine version stable. Quand tout est OK et que tout fonctionne bien, 
que les objectifs qui ont été fixés par les équipes de Debian sont atteints et 
après une période de gel et de chasse aux bugs, alors la version testing devient 
la nouvelle version officielle, la version stable.

**La distribution Unstable**, *Sid est son petit nom* est la version qui reçoit 
toutes les nouvelles versions de paquets, elle est au top des nouveautés mais pas 
très stable, c'est un laboratoire. Quelques aventuriers l'utilisent au quotidien.

**Experimental** n'est pas une distribution de Debian mais plutôt un dépôt ou 
l'on teste des versions de logiciels qui sont encore en Alpha ou en Beta.

![Toy Story © Disney & Pixar](img/toystory.jpg)

Toutes ces distributions ont un nom qui est choisi parmi les personnages du 
dessin animé Toy Story ®. Actuellement la distribution **stable s'appelle Stretch**, 
la distribution **testing s'appelle Buster **, et **oldstable s'appelle Jessie**. 
Experimental n'a pas de nom.

La distribution **unstable s'appelle Sid**. Mais qui c'est ce Sid ?  
Sid est le petit garçon dans Toy story® qui casse tous ses jouets 
([http://pixar.wikia.com/wiki/Sid_Phillips](http://pixar.wikia.com/wiki/Sid_Phillips)).  

Plus de détails sur la page dédiée du wiki Debian 
[https://wiki.debian.org/fr/DebianUnstable](https://wiki.debian.org/fr/DebianUnstable).

![sid](img/sid.jpg)  

